@@ -1,7 +1,6 @@
 # from __future__ import annotations
 
 from dataclasses import field
-from email import charset
 from typing import Any, Dict, List, Optional, Set
 
 # Use pydantic for type checking. It is slower, but not much of an issue for parsing.
@@ -10,7 +9,7 @@ from pydantic.dataclasses import dataclass
 import json
 import itertools
 
-from string import ascii_lowercase, ascii_uppercase, digits, punctuation, whitespace
+from string import ascii_lowercase, ascii_uppercase, digits, punctuation
 
 #region Helper functions
 
@@ -76,13 +75,13 @@ DEFAULT_CHARSETS: Dict[str,str] = {
   "lower": ascii_lowercase,
   "upper": ascii_uppercase,
   "digits": digits,
-  "symbols": punctuation + whitespace
+  "symbols": punctuation + ' '
 }
 
 ALPHABET_CHARSETS: Dict[str,str] = {
   "alphabet": ascii_lowercase + ascii_uppercase,
   "digits": digits,
-  "symbols": punctuation + whitespace
+  "symbols": punctuation + ' '
 }
 
 def SimplePCP(*args, **kwargs) -> 'PCP':
